@@ -17,9 +17,9 @@ file <- paste(system.file(package="dismo"), "/ex/bradypus.csv", sep="")
 # this is the file we will use:
 file
 
-# let's read it
-bradypus <- read.table(file,  header=TRUE,  sep=',')
-# lets inspect the values of the file
+# read it
+bradypus <- read.table(file,  header=TRUE,  sep=",")
+# inspect the values of the file
 # first rows
 head(bradypus)
 # we only need columns 2 and 3:
@@ -51,7 +51,7 @@ acgeo[1:4, c(1:5,7:10)]
 library(maptools)
 data(wrld_simpl)
 plot(wrld_simpl, xlim=c(-80,70), ylim=c(-60,10), axes=TRUE, 
-        col='light yellow')
+        col="light yellow")
 
 # restore the box around the map
 box()
@@ -109,50 +109,48 @@ acg <- acg[acg$lon < -50 & acg$lat > -50, ]
 
 
 ###################################################
-### code chunk number 10: sdm6
+### code chunk number 10: sdm6a
 ###################################################
 library(sp)
-# make a SpatialPointsDataFrame
 coordinates(acg) <- ~lon+lat
-projection(acg) <- CRS('+proj=lonlat')
+crs(acg) <- crs(wrld_simpl)
 class(acg)
-# use the coordinates to do a spatial query of the polygons
-# in wrld_simpl (a SpatialPolygonsDataFrame)
+
+
+###################################################
+### code chunk number 11: sdm6b
+###################################################
 class(wrld_simpl)
-ov <- overlay(acg, wrld_simpl)
+ovr <- over(acg, wrld_simpl)
 
-# ov has, for each point, the record number of wrld_simpl
-# we can use the record number to extract the country name 
-# first find the variable name
-names(wrld_simpl)
-head(wrld_simpl)
 
-# We need the variable 'NAME' in the data.frame of wrld_simpl
+###################################################
+### code chunk number 12: sdm6c
+###################################################
+head(ovr)
+cntr <- ovr$NAME
 
-cntr <- as.character(wrld_simpl$NAME[ov])
 
-# which points (identified by their record numbers) do not match 
-# any country (i.e. are in an ocean)
+###################################################
+### code chunk number 13: sdm6d
+###################################################
 i <- which(is.na(cntr))
 i
-# there are none (because we already removed the points that mapped in the ocean)
-
-# which points have coordinates that are in a different country than
-#  listed in the country field of the gbif record
 j <- which(cntr != acg$country)
 # for the mismatches, bind the country names of the polygons and points
 cbind(cntr, acg$country)[j,]
 
-# In this case the mismatch is probably because wrld_simpl is not
-# very precise as the records map to locations very close to the 
-# border between Bolivia and its neighbors.
+
+###################################################
+### code chunk number 14: sdm6d
+###################################################
 plot(acg)
 plot(wrld_simpl, add=T, border='blue', lwd=2)
 points(acg[j, ], col='red', pch=20, cex=2)
 
 
 ###################################################
-### code chunk number 11: sdm8
+### code chunk number 15: sdm8
 ###################################################
 georef <- subset(acaule, (is.na(lon) | is.na(lat)) & ! is.na(locality) )
 dim(georef)
@@ -160,7 +158,7 @@ georef[1:3,1:13]
 
 
 ###################################################
-### code chunk number 12: sdm9
+### code chunk number 16: sdm9
 ###################################################
 georef$cloc[4]
 b <- try(  geocode(georef$cloc[4]) )
@@ -168,7 +166,7 @@ b
 
 
 ###################################################
-### code chunk number 13: sdm10
+### code chunk number 17: sdm10
 ###################################################
 # create a RasterLayer with the extent of acgeo
 r <- raster(acg)
@@ -190,14 +188,14 @@ points(acsel, cex=1, col='red', pch='x')
 
 
 ###################################################
-### code chunk number 14: sdm12
+### code chunk number 18: sdm12
 ###################################################
 file <- paste(system.file(package="dismo"), '/ex/acaule.csv', sep='')
 acsel <- read.csv(file)
 
 
 ###################################################
-### code chunk number 15: sdm15a
+### code chunk number 19: sdm15a
 ###################################################
 # get the file names 
 files <- list.files(path=paste(system.file(package="dismo"), '/ex', 
@@ -214,7 +212,7 @@ bg <- randomPoints(mask, 500 )
 
 
 ###################################################
-### code chunk number 16: sdm15
+### code chunk number 20: sdm15
 ###################################################
 # set up the plotting area for two maps
 par(mfrow=c(1,2))
@@ -231,35 +229,35 @@ points(bg2, cex=0.5)
 
 
 ###################################################
-### code chunk number 17: sdm16a
+### code chunk number 21: sdm16a
 ###################################################
 file <- paste(system.file(package="dismo"), '/ex/acaule.csv', sep='')
 ac <- read.csv(file)
 
 
 ###################################################
-### code chunk number 18: sdm16b
+### code chunk number 22: sdm16b
 ###################################################
 coordinates(ac) <- ~lon+lat
-projection(ac) <- CRS('+proj=lonlat')
+projection(ac) <- CRS('+proj=longlat')
 
 
 ###################################################
-### code chunk number 19: sdm17
+### code chunk number 23: sdm17
 ###################################################
 # circles with a radius of 50 km
 x <- circles(ac, d=50000, lonlat=TRUE)
 
 
 ###################################################
-### code chunk number 20: sdm18
+### code chunk number 24: sdm18
 ###################################################
 library(rgeos)
 pol <-  gUnaryUnion(x@polygons)
 
 
 ###################################################
-### code chunk number 21: sdm19
+### code chunk number 25: sdm19
 ###################################################
 # sample randomly from all circles
 samp1 <- spsample(pol, 250, type='random', iter=25)
@@ -272,21 +270,22 @@ xy <- xyFromCell(mask, cells)
 
 
 ###################################################
-### code chunk number 22: sdm20
+### code chunk number 26: sdm20
 ###################################################
 plot(pol, axes=TRUE)
 points(xy, cex=0.75, pch=20, col='blue')
 
 
 ###################################################
-### code chunk number 23: sdm21a
+### code chunk number 27: sdm21a
 ###################################################
-o <- overlay(x@polygons, SpatialPoints(xy))
+spxy <- SpatialPoints(xy, proj4string=CRS('+proj=longlat'))
+o <- over(spxy, x@polygons)
 xyInside <- xy[!is.na(o), ]
 
 
 ###################################################
-### code chunk number 24: sdm21b
+### code chunk number 28: sdm21b
 ###################################################
 # extract cell numbers for the circles
 v <- extract(mask, x@polygons, cellnumbers=T)
@@ -306,7 +305,7 @@ plot(x@polygons, add=T)
 
 
 ###################################################
-### code chunk number 25: sdm22
+### code chunk number 29: sdm22
 ###################################################
 files <- list.files(path=paste(system.file(package="dismo"), 
               '/ex', sep=''), pattern='grd', full.names=TRUE )
@@ -321,7 +320,7 @@ plot(predictors)
 
 
 ###################################################
-### code chunk number 26: sdm23a
+### code chunk number 30: sdm23a
 ###################################################
 library(maptools)
 data(wrld_simpl)
@@ -332,7 +331,7 @@ bradypus  <- bradypus[,-1]
 
 
 ###################################################
-### code chunk number 27: sdm23b
+### code chunk number 31: sdm23b
 ###################################################
 # first layer of the RasterStack
 plot(predictors, 1)
@@ -344,7 +343,7 @@ points(bradypus, col='blue')
 
 
 ###################################################
-### code chunk number 28: sdm24a
+### code chunk number 32: sdm24a
 ###################################################
 presvals <- extract(predictors, bradypus)
 # setting random seed to always create the same
@@ -361,7 +360,7 @@ summary(sdmdata)
 
 
 ###################################################
-### code chunk number 29: sdm24b
+### code chunk number 33: sdm24b
 ###################################################
 # pairs plot of the values of the climate data 
 # at the bradypus occurrence sites.
@@ -369,7 +368,7 @@ pairs(sdmdata[,2:5], cex=0.1, fig=TRUE)
 
 
 ###################################################
-### code chunk number 30: sdm25
+### code chunk number 34: sdm25
 ###################################################
 m1 <- glm(pb ~ bio1 + bio5 + bio12, data=sdmdata)
 class(m1)
@@ -380,7 +379,7 @@ m2
 
 
 ###################################################
-### code chunk number 31: sdm26
+### code chunk number 35: sdm26
 ###################################################
 bc <- bioclim(presvals[,c('bio1', 'bio5', 'bio12')])
 class(bc)
@@ -389,7 +388,7 @@ pairs(bc)
 
 
 ###################################################
-### code chunk number 32: sdm27a
+### code chunk number 36: sdm27a
 ###################################################
 bio1 = c(40, 150, 200)
 bio5 = c(60, 115, 290)
@@ -401,13 +400,13 @@ predict(bc, pd)
 
 
 ###################################################
-### code chunk number 33: sdm27b
+### code chunk number 37: sdm27b
 ###################################################
 response(bc)
 
 
 ###################################################
-### code chunk number 34: sdm27c
+### code chunk number 38: sdm27c
 ###################################################
 names(predictors)
 p <- predict(predictors, m1)
@@ -415,7 +414,7 @@ plot(p)
 
 
 ###################################################
-### code chunk number 35: sdm28
+### code chunk number 39: sdm28
 ###################################################
 p <- rnorm(50, mean=0.7, sd=0.3)
 a <- rnorm(50, mean=0.4, sd=0.4)
@@ -430,7 +429,7 @@ boxplot(comb~group, col=c('blue', 'red'))
 
 
 ###################################################
-### code chunk number 36: sdm29
+### code chunk number 40: sdm29
 ###################################################
 group = c(rep(1, length(p)), rep(0, length(a))) 
 cor.test(comb, group)$estimate
@@ -440,7 +439,7 @@ auc
 
 
 ###################################################
-### code chunk number 37: sdm40
+### code chunk number 41: sdm40
 ###################################################
 e <- evaluate(p=p, a=a)
 class(e)
@@ -451,7 +450,7 @@ boxplot(e, col=c('blue', 'red'))
 
 
 ###################################################
-### code chunk number 38: sdm41
+### code chunk number 42: sdm41
 ###################################################
 samp <- sample(nrow(sdmdata), round(0.75 * nrow(sdmdata)))
 traindata <- sdmdata[samp,]
@@ -464,14 +463,14 @@ plot(e, 'ROC')
 
 
 ###################################################
-### code chunk number 39: sdm42
+### code chunk number 43: sdm42
 ###################################################
 pres <- sdmdata[sdmdata[,1] == 1, 2:9]
 back <- sdmdata[sdmdata[,1] == 0, 2:9]
 
 
 ###################################################
-### code chunk number 40: sdm43
+### code chunk number 44: sdm43
 ###################################################
 k <- 5
 group <- kfold(pres, k)
@@ -480,7 +479,7 @@ unique(group)
 
 
 ###################################################
-### code chunk number 41: sdm44
+### code chunk number 45: sdm44
 ###################################################
 e <- list()
 for (i in 1:k) {
@@ -492,7 +491,7 @@ for (i in 1:k) {
 
 
 ###################################################
-### code chunk number 42: sdm45a
+### code chunk number 46: sdm45a
 ###################################################
 auc <- sapply( e, function(x){slot(x, 'auc')} )
 auc
@@ -504,7 +503,7 @@ mean(auc)
 
 
 ###################################################
-### code chunk number 43: sdm45b
+### code chunk number 47: sdm45b
 ###################################################
 nr <- nrow(bradypus)
 s <- sample(nr, 0.25 * nr)
@@ -518,14 +517,14 @@ back_test <- backgr[s, ]
 
 
 ###################################################
-### code chunk number 44: sdm45b
+### code chunk number 48: sdm45b
 ###################################################
 sb <- ssb(pres_test, back_test, pres_train)
 sb[,1] / sb[,2]
 
 
 ###################################################
-### code chunk number 45: sdm45c
+### code chunk number 49: sdm45c
 ###################################################
 i <- pwdSample(pres_test, back_test, pres_train, n=1, tr=0.1)
 pres_test_pwd <- pres_test[!is.na(i[,1]), ]
@@ -535,7 +534,7 @@ sb2[1]/ sb2[2]
 
 
 ###################################################
-### code chunk number 46: sdm45d
+### code chunk number 50: sdm45d
 ###################################################
 bc <- bioclim(predictors, pres_train)
 evaluate(bc, p=pres_test, a=back_test, x=predictors)
@@ -543,7 +542,7 @@ evaluate(bc, p=pres_test_pwd, a=back_test_pwd, x=predictors)
 
 
 ###################################################
-### code chunk number 47: sdm46a
+### code chunk number 51: sdm46a
 ###################################################
 files <- list.files(path=paste(system.file(package="dismo"), 
               '/ex', sep=''), pattern='grd', full.names=TRUE )
@@ -562,13 +561,13 @@ sdmdata[,'biome'] = as.factor(sdmdata[,'biome'])
 
 
 ###################################################
-### code chunk number 48: sdm46b
+### code chunk number 52: sdm46b
 ###################################################
 pred_nf <- dropLayer(predictors, 'biome')
 
 
 ###################################################
-### code chunk number 49: sdm47
+### code chunk number 53: sdm47
 ###################################################
 group <- kfold(bradypus, 5)
 pres_train <- bradypus[group != 1, ]
@@ -576,13 +575,13 @@ pres_test <- bradypus[group == 1, ]
 
 
 ###################################################
-### code chunk number 50: sdm48
+### code chunk number 54: sdm48
 ###################################################
 ext = extent(-90, -32, -33, 23)
 
 
 ###################################################
-### code chunk number 51: sdm49
+### code chunk number 55: sdm49
 ###################################################
 backg <- randomPoints(pred_nf, n=1000, ext=ext, extf = 1.25)
 colnames(backg) = c('lon', 'lat')
@@ -592,7 +591,7 @@ backg_test <- backg[group == 1, ]
 
 
 ###################################################
-### code chunk number 52: sdm50
+### code chunk number 56: sdm50
 ###################################################
 r = raster(pred_nf, 1)
 plot(!is.na(r), col=c('white', 'light grey'), legend=FALSE)
@@ -604,28 +603,28 @@ points(pres_test, pch='+', col='blue')
 
 
 ###################################################
-### code chunk number 53: sdm60
+### code chunk number 57: sdm60
 ###################################################
 bc <- bioclim(pred_nf, pres_train)
 plot(bc, a=1, b=2, p=0.85)
 
 
 ###################################################
-### code chunk number 54: sdm61a
+### code chunk number 58: sdm61a
 ###################################################
 e <- evaluate(pres_test, backg_test, bc, pred_nf)
 e
 
 
 ###################################################
-### code chunk number 55: sdm61b
+### code chunk number 59: sdm61b
 ###################################################
 tr <- threshold(e, 'spec_sens')
 tr
 
 
 ###################################################
-### code chunk number 56: sdm62
+### code chunk number 60: sdm62
 ###################################################
 pb <- predict(pred_nf, bc, ext=ext, progress='')
 pb
@@ -638,7 +637,7 @@ points(pres_train, pch='+')
 
 
 ###################################################
-### code chunk number 57: sdm63
+### code chunk number 61: sdm63
 ###################################################
 dm <- domain(pred_nf, pres_train)
 e <- evaluate(pres_test, backg_test, dm, pred_nf)
@@ -654,7 +653,7 @@ points(pres_train, pch='+')
 
 
 ###################################################
-### code chunk number 58: sdm64
+### code chunk number 62: sdm64
 ###################################################
 mm <- mahal(pred_nf, pres_train)
 e <- evaluate(pres_test, backg_test, mm, pred_nf)
@@ -671,7 +670,7 @@ points(pres_train, pch='+')
 
 
 ###################################################
-### code chunk number 59: sdm65
+### code chunk number 63: sdm65
 ###################################################
 train <- rbind(pres_train, backg_train)
 pb_train <- c(rep(1, nrow(pres_train)), rep(0, nrow(backg_train)))
@@ -687,7 +686,7 @@ testbackg[ ,'biome'] = factor(testbackg[ ,'biome'], levels=1:14)
 
 
 ###################################################
-### code chunk number 60: sdm66
+### code chunk number 64: sdm66
 ###################################################
 # logistic regression:
 gm1 <- glm(pa ~ bio1 + bio5 + bio6 + bio7 + bio8 + bio12 + bio16 + bio17, 
@@ -705,7 +704,7 @@ ge2
 
 
 ###################################################
-### code chunk number 61: sdm67
+### code chunk number 65: sdm67
 ###################################################
 pg <- predict(predictors, gm2, ext=ext)
 par(mfrow=c(1,2))
@@ -719,7 +718,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 62: sdm68a
+### code chunk number 66: sdm68a
 ###################################################
 # checking if the jar file is present. If not, skip this bit
 jar <- paste(system.file(package="dismo"), "/java/maxent.jar", sep='')
@@ -733,7 +732,7 @@ if (file.exists(jar)) {
 
 
 ###################################################
-### code chunk number 63: sdm68b
+### code chunk number 67: sdm68b
 ###################################################
 if (file.exists(jar)) {
 	response(xm)
@@ -744,7 +743,7 @@ if (file.exists(jar)) {
 
 
 ###################################################
-### code chunk number 64: sdm69
+### code chunk number 68: sdm69
 ###################################################
 if (file.exists(jar)) {
 	e <- evaluate(pres_test, backg_test, xm, predictors)
@@ -763,7 +762,7 @@ if (file.exists(jar)) {
 
 
 ###################################################
-### code chunk number 65: sdm80
+### code chunk number 69: sdm80
 ###################################################
 library(randomForest)
 model <- pa ~ bio1 + bio5 + bio6 + bio7 + bio8 + bio12 + bio16 + bio17
@@ -788,7 +787,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 66: sdm81
+### code chunk number 70: sdm81
 ###################################################
 library(kernlab)
 svm <- ksvm(pa ~ bio1+bio5+bio6+bio7+bio8+bio12+bio16+bio17, data=envtrain)
@@ -807,7 +806,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 67: sdm82
+### code chunk number 71: sdm82
 ###################################################
 models <- stack(pb, pd, pm, pg, pr, ps)
 names(models) <- c("bioclim", "domain", "mahal", "glm", "rf", "svm")
@@ -815,14 +814,14 @@ plot(models)
 
 
 ###################################################
-### code chunk number 68: sdm83
+### code chunk number 72: sdm83
 ###################################################
 m <- mean(models)
 plot(m, main='average score')
 
 
 ###################################################
-### code chunk number 69: sdm84
+### code chunk number 73: sdm84
 ###################################################
 auc <- sapply(list(ge2, erf, esv), function(x) x@auc)
 w <- (auc-0.5)^2
@@ -831,7 +830,7 @@ plot(m2, main='weighted mean of three models')
 
 
 ###################################################
-### code chunk number 70: sdm100
+### code chunk number 74: sdm100
 ###################################################
 # first create a mask to predict to, and to use as a mask 
 # to only predict to land areas
@@ -854,7 +853,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 71: sdm102
+### code chunk number 75: sdm102
 ###################################################
 hull <- convHull(pres_train, lonlat=TRUE)
 e <- evaluate(hull, p=pres_test, a=backg_test)
@@ -869,7 +868,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 72: sdm104
+### code chunk number 76: sdm104
 ###################################################
 circ <- circles(pres_train, lonlat=TRUE)
 pc <- predict(seamask, circ, mask=TRUE)
@@ -888,7 +887,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 73: sdm106
+### code chunk number 77: sdm106
 ###################################################
 idwm <- geoIDW(p=pres_train, a=data.frame(back_train))
 
@@ -910,7 +909,7 @@ points(backg_train, pch='-', cex=0.25)
 
 
 ###################################################
-### code chunk number 74: sdm108
+### code chunk number 78: sdm108
 ###################################################
 # take a smallish sample of the background training data
 va <- data.frame(back_train[sample(nrow(back_train), 100), ])
